@@ -66,13 +66,20 @@ void chinv2  (double **matrix, int n);
 int cholesky2(double **matrix, int n, double toler);
 void chsolve2(double **matrix, int n, double *y);
 void chinv3(double **matrix , int n, int m, double *fdiag);
+void chinv5(double **matrix , int n, int flag);
 int cholesky3(double **matrix, int n, int m, double *diag, double toler);
+int cholesky5(double **matrix, int n, double toler);
 void chsolve3(double **matrix, int n, int m, double *diag, double *y);
+void chsolve5(double **matrix, int n, double *y, int flag);	
 
 SEXP concordance1(SEXP y, SEXP wt2,  SEXP indx2, SEXP ntree2);
  
 SEXP concordance2(SEXP y,     SEXP wt2,  SEXP indx2, SEXP ntree2,
                   SEXP sortstop, SEXP sortstart) ;
+SEXP concordance3(SEXP y,        SEXP x2, SEXP wt2, SEXP timewt2, 
+                  SEXP sortstop, SEXP doresid2);
+SEXP concordance4(SEXP y, SEXP x2, SEXP wt2, SEXP timewt2, 
+                  SEXP sortstart, SEXP sortstop, SEXP doresid2); 
 
 void cox_callback(int which, double *coef, double *first, double *second,
 		  double *penalty, int *flag, int p, SEXP fexpr, SEXP rho);
@@ -135,11 +142,16 @@ void coxscore(Sint   *nx,      Sint   *nvarx,    double *y,
 	      double *scratch);
 
 double coxsafe(double x);
-double **dmatrix(double *array, int ncol, int nrow);
+double **dmatrix(double *array, int nrow, int ncol);
+int    **imatrix(int *array, int nrow, int ncol);
 
 SEXP finegray(SEXP tstart2, SEXP tstop2,   SEXP ctime2,   SEXP cprob2, 
 	      SEXP extend2, SEXP keep2);
 
+SEXP gchol(SEXP matrix2, SEXP toler2);
+SEXP gchol_solve(SEXP x2, SEXP y2, SEXP flag2);
+SEXP gchol_inv(SEXP matrix, SEXP flag2);
+
 void init_doloop(int min, int max);
 int doloop      (int nloops, int *index);
 
@@ -176,9 +188,9 @@ void survdiff2(Sint   *nn,     Sint   *nngroup,    Sint   *nstrat,
 
 void survfit4(Sint *n,	Sint *dd,  double *x1,  double *x2) ;
 
- SEXP survfitci(SEXP ftime2,  SEXP sort12,  SEXP sort22, SEXP ntime2,
+SEXP survfitci(SEXP ftime2,     SEXP sort12,  SEXP sort22, SEXP ntime2,
                     SEXP status2, SEXP cstate2, SEXP wt2,  SEXP id2,
-                    SEXP p2,  SEXP sefit2) ;
+                    SEXP p2,      SEXP i02,     SEXP sefit2) ;
   
 SEXP survreg6(SEXP maxiter2,   SEXP nvarx,  SEXP y,
 	      SEXP ny2,        SEXP covar2, SEXP wtx,
